@@ -1,5 +1,5 @@
 // =================================================================================================
-// Copyright 2002-2007 Adobe Systems Incorporated
+// Copyright 2002-2008 Adobe Systems Incorporated
 // All Rights Reserved.
 //
 // NOTICE:  Adobe permits you to use, modify, and distribute this file in accordance with the terms
@@ -25,11 +25,12 @@
 using namespace std;
 
 #if XMP_WinBuild
+#ifdef _MSC_VER
 	#pragma warning ( disable : 4533 )	// initialization of '...' is skipped by 'goto ...'
 	#pragma warning ( disable : 4702 )	// unreachable code
 	#pragma warning ( disable : 4800 )	// forcing value to bool 'true' or 'false' (performance warning)
 #endif
-
+#endif
 
 // *** Use the XMP_PropIsXyz (Schema, Simple, Struct, Array, ...) macros
 // *** Add debug codegen checks, e.g. that typical masking operations really work
@@ -302,7 +303,7 @@ AppendNodeValue ( XMP_VarString & outputStr, const XMP_VarString & value, bool f
 				XMP_Assert ( (ch == kTab) || (ch == kLF) || (ch == kCR) );
 
 				char hexBuf[16];
-				memcpy ( hexBuf, "&#xn;", 10 );	// AUDIT: Length of "&#xn;" is 5, hexBuf size is 16.
+				memcpy ( hexBuf, "&#xn;", 5 );
 				hexBuf[3] = kHexDigits[ch&0xF];
 				outputStr.append ( hexBuf, 5 );
 
@@ -1092,10 +1093,12 @@ SerializeAsRDF ( const XMPMeta & xmpObj,
 	}
 
 	// Write the xmpmeta element's start tag.
-	for ( level = baseIndent; level > 0; --level ) headStr += indentStr;
-	headStr += kRDF_XMPMetaStart;
-	headStr += kXMPCore_VersionMessage "\">";
-	headStr += newline;
+	if ( ! (options & kXMP_OmitXMPMetaElement) ) {
+		for ( level = baseIndent; level > 0; --level ) headStr += indentStr;
+		headStr += kRDF_XMPMetaStart;
+		headStr += kXMPCore_VersionMessage "\">";
+		headStr += newline;
+	}
 
 	// Write the rdf:RDF start tag.
 	for ( level = baseIndent+1; level > 0; --level ) headStr += indentStr;
@@ -1127,9 +1130,11 @@ SerializeAsRDF ( const XMPMeta & xmpObj,
 	headStr += newline;
 
 	// Write the xmpmeta end tag.
-	for ( level = baseIndent; level > 0; --level ) headStr += indentStr;
-	headStr += kRDF_XMPMetaEnd;
-	headStr += newline;
+	if ( ! (options & kXMP_OmitXMPMetaElement) ) {
+		for ( level = baseIndent; level > 0; --level ) headStr += indentStr;
+		headStr += kRDF_XMPMetaEnd;
+		headStr += newline;
+	}
 	
 	// Write the packet trailer PI into the tail string as UTF-8.
 	tailStr.erase();
@@ -1287,11 +1292,11 @@ XMPMeta::SerializeToBuffer ( XMP_StringPtr * rdfString,
 		} else {
 
 			std::string padStr ( "    " );  padStr[0] = padStr[1] = padStr[2] = 0;	// Assume big endian.
-			UTF8_to_UTF32_Proc Converter = UTF8_to_UTF32BE;
+//			UTF8_to_UTF32_Proc Converter = UTF8_to_UTF32BE;
 
 			if ( charEncoding & _XMP_LittleEndian_Bit ) {
 				padStr[0] = ' '; padStr[1] = padStr[2] = padStr[3] = 0;
-				Converter = UTF8_to_UTF32LE;
+//				Converter = UTF8_to_UTF32LE;
 			}
 			
 			utf8Str.swap ( *sOutputStr );
